@@ -157,7 +157,10 @@ describe('sourcemap-codec', () => {
 	describe('decode()', () => {
 		tests.forEach((test, i) => {
 			it('decodes sample ' + i, () => {
-				assert.deepEqual(decode(test.encoded), test.decoded);
+				const expected = test.decoded.map(line => {
+					return line.map(segment => new Int32Array(segment));
+				});
+				assert.deepEqual(decode(test.encoded), expected);
 			});
 		});
 	});
